@@ -11,16 +11,21 @@ typedef Eo Ecore_Audio;
 #ifndef _ECORE_AUDIO_EO_TYPES
 #define _ECORE_AUDIO_EO_TYPES
 
+/** Ecore audio format type
+ *
+ * @ingroup Ecore_Audio
+ */
 typedef enum
 {
-  ECORE_AUDIO_FORMAT_AUTO = 0, /** Automatically detect the format (for inputs)
+  ECORE_AUDIO_FORMAT_AUTO = 0, /**< Automatically detect the format (for inputs)
                                 */
-  ECORE_AUDIO_FORMAT_RAW, /** RAW samples (float) */
-  ECORE_AUDIO_FORMAT_WAV, /** WAV format */
-  ECORE_AUDIO_FORMAT_OGG, /** OGG */
-  ECORE_AUDIO_FORMAT_FLAC, /** FLAC, the Free Lossless Audio Codec */
-  ECORE_AUDIO_FORMAT_MP3, /** MP3 (not supported) */
-  ECORE_AUDIO_FORMAT_LAST /** Sentinel value, do not use */
+  ECORE_AUDIO_FORMAT_RAW, /**< RAW samples (float) */
+  ECORE_AUDIO_FORMAT_WAV, /**< WAV format */
+  ECORE_AUDIO_FORMAT_OGG, /**< OGG */
+  ECORE_AUDIO_FORMAT_FLAC, /**< FLAC, the Free Lossless Audio Codec */
+  ECORE_AUDIO_FORMAT_MP3, /**< MP3 (not supported) */
+  ECORE_AUDIO_FORMAT_LAST /**< Sentinel value to indicate last enum field during
+                           * iteration */
 } Ecore_Audio_Format;
 
 
@@ -31,34 +36,13 @@ typedef enum
  */
 #define ECORE_AUDIO_CLASS ecore_audio_class_get()
 
-EWAPI const Eo_Class *ecore_audio_class_get(void);
+EWAPI const Efl_Class *ecore_audio_class_get(void);
 
 /**
- * @brief Name of the object
+ * @brief Pauses state of the object
  *
- * @param[in] name Name
- *
- * @since 1.8
- *
- * @ingroup Ecore_Audio
- */
-EOAPI void ecore_audio_obj_name_set(Eo *obj, const char *name);
-
-/**
- * @brief Name of the object
- *
- * @return Name
- *
- * @since 1.8
- *
- * @ingroup Ecore_Audio
- */
-EOAPI const char *ecore_audio_obj_name_get(const Eo *obj);
-
-/**
- * @brief Pause state of the object
- *
- * @param[in] paused true if object is paused, false if not
+ * @param[in] obj The object.
+ * @param[in] paused @c true if object is paused, @c false otherwise
  *
  * @since 1.8
  *
@@ -67,9 +51,11 @@ EOAPI const char *ecore_audio_obj_name_get(const Eo *obj);
 EOAPI void ecore_audio_obj_paused_set(Eo *obj, Eina_Bool paused);
 
 /**
- * @brief Pause state of the object
+ * @brief Pauses state of the object
  *
- * @return true if object is paused, false if not
+ * @param[in] obj The object.
+ *
+ * @return @c true if object is paused, @c false otherwise
  *
  * @since 1.8
  *
@@ -80,6 +66,7 @@ EOAPI Eina_Bool ecore_audio_obj_paused_get(const Eo *obj);
 /**
  * @brief Volume of the object
  *
+ * @param[in] obj The object.
  * @param[in] volume The volume
  *
  * @since 1.8
@@ -91,6 +78,8 @@ EOAPI void ecore_audio_obj_volume_set(Eo *obj, double volume);
 /**
  * @brief Volume of the object
  *
+ * @param[in] obj The object.
+ *
  * @return The volume
  *
  * @since 1.8
@@ -105,24 +94,11 @@ EOAPI double ecore_audio_obj_volume_get(const Eo *obj);
  * What sources are supported depends on the actual object. For example, the
  * libsndfile class accepts WAV, OGG, FLAC files as source.
  *
- * @return the source to set to (i.e. file, URL, device)
+ * @param[in] obj The object.
+ * @param[in] source The source to set to (i.e. file, URL, device)
  *
- * @since 1.8
- *
- * @ingroup Ecore_Audio
- */
-EOAPI const char *ecore_audio_obj_source_get(const Eo *obj);
-
-/**
- * @brief Source of the object
- *
- * What sources are supported depends on the actual object. For example, the
- * libsndfile class accepts WAV, OGG, FLAC files as source.
- *
- * @param[in] source the source to set to (i.e. file, URL, device)
- *
- * @return true if the source was set correctly (i.e. the file was opened),
- * EINA_FALSE otherwise
+ * @return @c true if the source was set correctly (i.e. the file was opened),
+ * @c false otherwise
  *
  * @since 1.8
  *
@@ -131,32 +107,33 @@ EOAPI const char *ecore_audio_obj_source_get(const Eo *obj);
 EOAPI Eina_Bool ecore_audio_obj_source_set(Eo *obj, const char *source);
 
 /**
- * @brief Format of the object.
+ * @brief Source of the object
  *
- * Get the format of the object
+ * What sources are supported depends on the actual object. For example, the
+ * libsndfile class accepts WAV, OGG, FLAC files as source.
  *
- * After setting the source if the format was ECORE_AUDIO_FORMAT_AUTO this
- * function will now return the actual format.
+ * @param[in] obj The object.
  *
- * @return the format of the object
+ * @return The source to set to (i.e. file, URL, device)
  *
  * @since 1.8
  *
  * @ingroup Ecore_Audio
  */
-EOAPI Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
+EOAPI const char *ecore_audio_obj_source_get(const Eo *obj);
 
 /**
  * @brief Format of the object.
  *
- * Set the format of the object
+ * Sets the format of the object
  *
  * What formats are supported depends on the actual object. Default is
  * ECORE_AUDIO_FORMAT_AUTO
  *
- * @param[in] format the format of the object
+ * @param[in] obj The object.
+ * @param[in] format The audio format of the object
  *
- * @return true if the format was supported, false otherwise
+ * @return @c true if the format was supported, @c false otherwise
  *
  * @since 1.8
  *
@@ -165,18 +142,36 @@ EOAPI Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
 EOAPI Eina_Bool ecore_audio_obj_format_set(Eo *obj, Ecore_Audio_Format format);
 
 /**
- * @brief Set the virtual IO functions
+ * @brief Format of the object.
  *
- * @param[in] vio the @ref Ecore_Audio_Vio struct with the function callbacks
- * @param[in] data user data to pass to the VIO functions
- * @param[in] free_func this function takes care to clean up @c data when he
+ * Gets the format of the object
+ *
+ * After setting the source if the format was ECORE_AUDIO_FORMAT_AUTO this
+ * function will now return the actual format.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The audio format of the object
+ *
+ * @since 1.8
+ *
+ * @ingroup Ecore_Audio
+ */
+EOAPI Ecore_Audio_Format ecore_audio_obj_format_get(const Eo *obj);
+
+/**
+ * @brief Sets the virtual IO functions
+ *
+ * @param[in] obj The object.
+ * @param[in] vio The @ref Ecore_Audio_Vio struct with the function callbacks
+ * @param[in] data User data to pass to the VIO functions
+ * @param[in] free_func This function takes care to clean up @c data when he
  * VIO is destroyed. NULL means do nothing.
  *
  * @since 1.8
  *
  * @ingroup Ecore_Audio
  */
-EOAPI void ecore_audio_obj_vio_set(Eo *obj, Ecore_Audio_Vio *vio, void *data, eo_key_data_free_func free_func);
-
+EOAPI void ecore_audio_obj_vio_set(Eo *obj, Ecore_Audio_Vio *vio, void *data, efl_key_data_free_func free_func);
 
 #endif
