@@ -6,14 +6,14 @@
 
 /** Permitted directions for dragging objects.
  *
- * @ingroup Efl_Ui_Drag
+ * @ingroup Efl_Ui
  */
 typedef enum
 {
   EFL_UI_DRAG_DIR_NONE = 0, /**< Not draggable in any direction. */
-  EFL_UI_DRAG_DIR_X = 1 /* 0 */, /**< Draggable horizontally. */
-  EFL_UI_DRAG_DIR_Y = 2 /* 0 */, /**< Draggable vertically. */
-  EFL_UI_DRAG_DIR_XY = 3 /* 0 */ /**< Draggable in both directions. */
+  EFL_UI_DRAG_DIR_X = 1, /**< Draggable horizontally. */
+  EFL_UI_DRAG_DIR_Y = 2, /**< Draggable vertically. */
+  EFL_UI_DRAG_DIR_XY = 3 /**< Draggable in both directions. */
 } Efl_Ui_Drag_Dir;
 
 
