@@ -44,22 +44,6 @@ typedef enum
                                       * field during iteration */
 } Elm_Scroller_Single_Direction;
 
-/** Type that blocks the scroll movement in one or more direction.
- *
- * @since 1.8
- *
- * @ingroup Elm_Scroller
- */
-typedef enum
-{
-  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1 /* 0 >> 0 */, /**< Do not block movements
-                                                    */
-  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2 /* 0 >> 0 */, /**< Block vertical
-                                                          * movements */
-  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /* 0 >> 0 */ /**< Block horizontal
-                                                           * movements */
-} Elm_Scroller_Movement_Block;
-
 
 #endif
 
@@ -133,6 +117,7 @@ typedef enum
 
 
 
+
 
 
 #endif
