@@ -28,6 +28,7 @@ EWAPI const Efl_Class *elm_widget_item_class_get(void);
  * parent window's canvas. It will instead be limited only by the size of the
  * display.
  *
+ * @param[in] obj The object.
  * @param[in] disable If @c true, size restrictions are disabled
  *
  * @return @c false on failure, @c true on success
@@ -43,6 +44,8 @@ EOAPI Eina_Bool elm_wdg_item_tooltip_window_mode_set(Eo *obj, Eina_Bool disable)
  * parent window's canvas. It will instead be limited only by the size of the
  * display.
  *
+ * @param[in] obj The object.
+ *
  * @return If @c true, size restrictions are disabled
  *
  * @ingroup Elm_Widget_Item
@@ -58,6 +61,7 @@ EOAPI Eina_Bool elm_wdg_item_tooltip_window_mode_get(const Eo *obj);
  *
  * See: elm_object_tooltip_style_set() for more details.
  *
+ * @param[in] obj The object.
  * @param[in] style The theme style used/to use (default, transparent, ...)
  *
  * @ingroup Elm_Widget_Item
@@ -73,6 +77,8 @@ EOAPI void elm_wdg_item_tooltip_style_set(Eo *obj, const char *style);
  *
  * See: elm_object_tooltip_style_set() for more details.
  *
+ * @param[in] obj The object.
+ *
  * @return The theme style used/to use (default, transparent, ...)
  *
  * @ingroup Elm_Widget_Item
@@ -92,6 +98,7 @@ EOAPI const char *elm_wdg_item_tooltip_style_get(const Eo *obj);
  * If this function is called twice for an object, a previously set cursor will
  * be unset on the second call.
  *
+ * @param[in] obj The object.
  * @param[in] cursor The cursor type's name
  *
  * @ingroup Elm_Widget_Item
@@ -111,6 +118,8 @@ EOAPI void elm_wdg_item_cursor_set(Eo *obj, const char *cursor);
  * If this function is called twice for an object, a previously set cursor will
  * be unset on the second call.
  *
+ * @param[in] obj The object.
+ *
  * @return The cursor type's name
  *
  * @ingroup Elm_Widget_Item
@@ -129,6 +138,7 @@ EOAPI const char *elm_wdg_item_cursor_get(const Eo *obj);
  * @warning Before you set a cursor style you should have defined a custom
  * cursor previously on the item, with @ref elm_wdg_item_cursor_set
  *
+ * @param[in] obj The object.
  * @param[in] style The theme style to use/in use (e.g. $"default",
  * $"transparent", etc)
  *
@@ -148,6 +158,8 @@ EOAPI void elm_wdg_item_cursor_style_set(Eo *obj, const char *style);
  * @warning Before you set a cursor style you should have defined a custom
  * cursor previously on the item, with @ref elm_wdg_item_cursor_set
  *
+ * @param[in] obj The object.
+ *
  * @return The theme style to use/in use (e.g. $"default", $"transparent", etc)
  *
  * @ingroup Elm_Widget_Item
@@ -164,6 +176,7 @@ EOAPI const char *elm_wdg_item_cursor_style_get(const Eo *obj);
  * @note By default, cursors will only be looked for between those provided by
  * the rendering engine.
  *
+ * @param[in] obj The object.
  * @param[in] engine_only Use @c true to have cursors looked for only on those
  * provided by the rendering engine, @c false to have them searched on the
  * widget's theme, as well.
@@ -182,6 +195,8 @@ EOAPI void elm_wdg_item_cursor_engine_only_set(Eo *obj, Eina_Bool engine_only);
  * @note By default, cursors will only be looked for between those provided by
  * the rendering engine.
  *
+ * @param[in] obj The object.
+ *
  * @return Use @c true to have cursors looked for only on those provided by the
  * rendering engine, @c false to have them searched on the widget's theme, as
  * well.
@@ -197,12 +212,13 @@ EOAPI Eina_Bool elm_wdg_item_cursor_engine_only_get(const Eo *obj);
  * already set as a content object in the same part, previous object will be
  * deleted automatically.
  *
+ * @param[in] obj The object.
  * @param[in] part The content part name  (NULL for the default content)
  * @param[in] content The content of the object item
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI void elm_wdg_item_part_content_set(Eo *obj, const char * part, Efl_Canvas_Object *content);
+EOAPI void elm_wdg_item_part_content_set(Eo *obj, const char *part, Efl_Canvas_Object *content);
 
 /**
  * @brief Control a content of an object item
@@ -211,67 +227,73 @@ EOAPI void elm_wdg_item_part_content_set(Eo *obj, const char * part, Efl_Canvas_
  * already set as a content object in the same part, previous object will be
  * deleted automatically.
  *
+ * @param[in] obj The object.
  * @param[in] part The content part name  (NULL for the default content)
  *
  * @return The content of the object item
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI Efl_Canvas_Object *elm_wdg_item_part_content_get(const Eo *obj, const char * part);
+EOAPI Efl_Canvas_Object *elm_wdg_item_part_content_get(const Eo *obj, const char *part);
 
 /**
  * @brief Control a label of an object item
  *
  * @note Elementary object items may have many labels
  *
+ * @param[in] obj The object.
  * @param[in] part The text part name (NULL for the default label)
  * @param[in] label Text of the label
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI void elm_wdg_item_part_text_set(Eo *obj, const char * part, const char *label);
+EOAPI void elm_wdg_item_part_text_set(Eo *obj, const char *part, const char *label);
 
 /**
  * @brief Control a label of an object item
  *
  * @note Elementary object items may have many labels
  *
+ * @param[in] obj The object.
  * @param[in] part The text part name (NULL for the default label)
  *
  * @return Text of the label
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI const char *elm_wdg_item_part_text_get(const Eo *obj, const char * part);
+EOAPI const char *elm_wdg_item_part_text_get(const Eo *obj, const char *part);
 
 #ifdef ELM_WIDGET_ITEM_PROTECTED
 /**
  * @brief Save additional text part content
  *
+ * @param[in] obj The object.
  * @param[in] part Part name
  * @param[in] label Label name
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI void elm_wdg_item_part_text_custom_set(Eo *obj, const char * part, const char *label);
+EOAPI void elm_wdg_item_part_text_custom_set(Eo *obj, const char *part, const char *label);
 #endif
 
 #ifdef ELM_WIDGET_ITEM_PROTECTED
 /**
  * @brief Get additional text part content
  *
+ * @param[in] obj The object.
  * @param[in] part Part name
  *
  * @return Label name
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI const char *elm_wdg_item_part_text_custom_get(const Eo *obj, const char * part);
+EOAPI const char *elm_wdg_item_part_text_custom_get(const Eo *obj, const char *part);
 #endif
 
 /**
  * @brief Control the object item focused
  *
+ * @param[in] obj The object.
  * @param[in] focused The focused state
  *
  * @since 1.10
@@ -283,6 +305,8 @@ EOAPI void elm_wdg_item_focus_set(Eo *obj, Eina_Bool focused);
 /**
  * @brief Control the object item focused
  *
+ * @param[in] obj The object.
+ *
  * @return The focused state
  *
  * @since 1.10
@@ -294,6 +318,7 @@ EOAPI Eina_Bool elm_wdg_item_focus_get(const Eo *obj);
 /**
  * @brief Control the style of an object item
  *
+ * @param[in] obj The object.
  * @param[in] style The style of object item
  *
  * @since 1.9
@@ -305,6 +330,8 @@ EOAPI void elm_wdg_item_style_set(Eo *obj, const char *style);
 /**
  * @brief Control the style of an object item
  *
+ * @param[in] obj The object.
+ *
  * @return The style of object item
  *
  * @since 1.9
@@ -324,6 +351,7 @@ EOAPI const char *elm_wdg_item_style_get(const Eo *obj);
  * This sets the state for the widget item, either disabling it or enabling it
  * back.
  *
+ * @param[in] obj The object.
  * @param[in] disable @c true, if the widget item is disabled, @c false if it's
  * enabled (or on errors)
  *
@@ -342,6 +370,8 @@ EOAPI void elm_wdg_item_disabled_set(Eo *obj, Eina_Bool disable);
  * This sets the state for the widget item, either disabling it or enabling it
  * back.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true, if the widget item is disabled, @c false if it's enabled
  * (or on errors)
  *
@@ -352,6 +382,8 @@ EOAPI Eina_Bool elm_wdg_item_disabled_get(const Eo *obj);
 /**
  * @brief Get highlight order
  *
+ * @param[in] obj The object.
+ *
  * @return List of evas canvas objects
  *
  * @since 1.8
@@ -363,6 +395,7 @@ EOAPI const Eina_List *elm_wdg_item_access_order_get(Eo *obj);
 /**
  * @brief Set highlight order
  *
+ * @param[in] obj The object.
  * @param[in] objs Order of objects to pass highlight
  *
  * @since 1.8
@@ -377,18 +410,14 @@ EOAPI void elm_wdg_item_access_order_set(Eo *obj, Eina_List *objs);
  * @note This returns the widget object itself that an item belongs to. Note:
  * Every elm_object_item supports this API
  *
+ * @param[in] obj The object.
+ *
  * @return The widget object
  *
  * @ingroup Elm_Widget_Item
  */
 EOAPI Efl_Canvas_Object *elm_wdg_item_widget_get(const Eo *obj);
 
-/** Delete the given item.
- *
- * @ingroup Elm_Widget_Item
- */
-EOAPI void elm_wdg_item_del(Eo *obj);
-
 #ifdef ELM_WIDGET_ITEM_PROTECTED
 /** notify deletion of widget item
  *
@@ -406,6 +435,7 @@ EOAPI void elm_wdg_item_pre_notify_del(Eo *obj);
  *
  * See: elm_object_tooltip_text_set() for more details.
  *
+ * @param[in] obj The object.
  * @param[in] text The text to set in the content.
  *
  * @ingroup Elm_Widget_Item
@@ -416,6 +446,7 @@ EOAPI void elm_wdg_item_tooltip_text_set(Eo *obj, const char *text);
 /**
  * @brief Set widget item tooltip as a text string
  *
+ * @param[in] obj The object.
  * @param[in] text Tooltip text
  *
  * @ingroup Elm_Widget_Item
@@ -432,6 +463,7 @@ EOAPI void elm_wdg_item_tooltip_translatable_text_set(Eo *obj, const char *text)
  *
  * See: elm_object_tooltip_unset() for more details. See:
  * @ref elm_wdg_item_tooltip_content_cb_set
+ * @param[in] obj The object.
  *
  * @ingroup Elm_Widget_Item
  */
@@ -446,6 +478,7 @@ EOAPI void elm_wdg_item_tooltip_unset(Eo *obj);
  * bringing it back to defaults (no custom style set).
  *
  * See: elm_object_cursor_unset() See: @ref elm_wdg_item_cursor_set
+ * @param[in] obj The object.
  *
  * @ingroup Elm_Widget_Item
  */
@@ -456,6 +489,7 @@ EOAPI void elm_wdg_item_cursor_unset(Eo *obj);
  *
  * @note Elementary object items may have many contents
  *
+ * @param[in] obj The object.
  * @param[in] part The content part name to unset (NULL for the default
  * content)
  *
@@ -480,6 +514,7 @@ EOAPI void elm_wdg_item_part_text_custom_update(Eo *obj);
  * object of the object item. Globs can occur in either the emission or source
  * name.
  *
+ * @param[in] obj The object.
  * @param[in] emission The signal's name.
  * @param[in] source The signal's source.
  * @param[in] func The callback function to be executed when the signal is
@@ -503,6 +538,7 @@ EOAPI void elm_wdg_item_signal_callback_add(Eo *obj, const char *emission, const
  *
  * See: @ref elm_wdg_item_signal_callback_add
  *
+ * @param[in] obj The object.
  * @param[in] emission The signal's name.
  * @param[in] source The signal's source.
  * @param[in] func The callback function to be executed when the signal is
@@ -524,6 +560,7 @@ EOAPI void *elm_wdg_item_signal_callback_del(Eo *obj, const char *emission, cons
  * fields. Don't use this unless you want to also handle resetting of part
  * states to default on every unrealize in case of genlist/gengrid.
  *
+ * @param[in] obj The object.
  * @param[in] emission The signal's name.
  * @param[in] source The signal's source.
  *
@@ -534,6 +571,7 @@ EOAPI void elm_wdg_item_signal_emit(Eo *obj, const char *emission, const char *s
 /**
  * @brief Set the text to read out when in accessibility mode
  *
+ * @param[in] obj The object.
  * @param[in] txt The text that describes the widget to people with poor or no
  * vision
  *
@@ -544,6 +582,8 @@ EOAPI void elm_wdg_item_access_info_set(Eo *obj, const char *txt);
 /**
  * @brief Get an accessible object of the object item.
  *
+ * @param[in] obj The object.
+ *
  * @return Accessible object of the object item or NULL for any error
  *
  * @since 1.8
@@ -566,6 +606,7 @@ EOAPI Efl_Canvas_Object *elm_wdg_item_access_object_get(const Eo *obj);
  * Elementary that will have its own translatable strings, that should not be
  * mixed with those of programs using the library.
  *
+ * @param[in] obj The object.
  * @param[in] part The name of the part to set
  * @param[in] domain The translation domain to use
  * @param[in] label The original, non-translated text to set
@@ -583,6 +624,7 @@ EOAPI void elm_wdg_item_domain_translatable_part_text_set(Eo *obj, const char *p
  * @ref elm_wdg_item_part_text_get will return the translation returned by
  * @c gettext(). To get the original string use this function.
  *
+ * @param[in] obj The object.
  * @param[in] part The name of the part that was set
  *
  * @return The original, untranslated string
@@ -613,6 +655,7 @@ EOAPI void elm_wdg_item_translate(Eo *obj);
  * See: @ref elm_wdg_item_domain_translatable_part_text_set See:
  * @ref elm_wdg_item_part_text_set See: elm_policy()
  *
+ * @param[in] obj The object.
  * @param[in] part The part name of the translatable text
  * @param[in] domain The translation domain to use
  * @param[in] translatable @c true, the part text will be translated
@@ -646,6 +689,8 @@ EOAPI void elm_wdg_item_domain_part_text_translatable_set(Eo *obj, const char *p
  *
  * See: @ref elm_wdg_item_untrack See: @ref elm_wdg_item_track_get
  *
+ * @param[in] obj The object.
+ *
  * @return The track object
  *
  * @since 1.8
@@ -662,6 +707,8 @@ EOAPI Efl_Canvas_Object *elm_wdg_item_track(Eo *obj);
  *
  * See: @ref elm_wdg_item_track See: @ref elm_wdg_item_track_get
  *
+ * @param[in] obj The object.
+ *
  * @since 1.8
  *
  * @ingroup Elm_Widget_Item
@@ -680,6 +727,8 @@ EOAPI void elm_wdg_item_untrack(Eo *obj);
  *
  * See: @ref elm_wdg_item_track See: @ref elm_wdg_item_track_get
  *
+ * @param[in] obj The object.
+ *
  * @return Track object reference count
  *
  * @since 1.8
@@ -701,6 +750,7 @@ EOAPI void elm_wdg_item_track_cancel(Eo *obj);
  *
  * @note Every elm_object_item supports this API
  *
+ * @param[in] obj The object.
  * @param[in] del_cb The function called
  *
  * @ingroup Elm_Widget_Item
@@ -718,6 +768,7 @@ EOAPI void elm_wdg_item_del_cb_set(Eo *obj, Evas_Smart_Cb del_cb);
  *
  * See: elm_object_tooltip_content_cb_set() for more details.
  *
+ * @param[in] obj The object.
  * @param[in] func The function used to create the tooltip contents.
  * @param[in] data What to provide to @c func as callback data/context.
  * @param[in] del_cb Called when data is not needed anymore, either when
@@ -733,6 +784,8 @@ EOAPI void elm_wdg_item_tooltip_content_cb_set(Eo *obj, Elm_Tooltip_Item_Content
 /**
  * @brief Register object item as an accessible object.
  *
+ * @param[in] obj The object.
+ *
  * @return Accessible object of the object item or NULL for any error
  *
  * @since 1.8
@@ -766,19 +819,17 @@ EOAPI void elm_wdg_item_disable(Eo *obj);
 #endif
 
 #ifdef ELM_WIDGET_ITEM_PROTECTED
-/**
- * @brief Delete pre widget item
- *
- * @return @c true on success, @c false otherwise
+/** Delete pre widget item
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI Eina_Bool elm_wdg_item_del_pre(Eo *obj);
+EOAPI void elm_wdg_item_del_pre(Eo *obj);
 #endif
 
 /**
  * @brief Get the next object with specific focus direction.
  *
+ * @param[in] obj The object.
  * @param[in] dir Focus direction
  *
  * @return Focus next object
@@ -787,11 +838,12 @@ EOAPI Eina_Bool elm_wdg_item_del_pre(Eo *obj);
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI Efl_Canvas_Object *elm_wdg_item_focus_next_object_get(const Eo *obj, Elm_Focus_Direction dir);
+EOAPI Efl_Canvas_Object *elm_wdg_item_focus_next_object_get(const Eo *obj, Efl_Ui_Focus_Direction dir);
 
 /**
  * @brief Set the next object with specific focus direction.
  *
+ * @param[in] obj The object.
  * @param[in] next Focus next object
  * @param[in] dir Focus direction
  *
@@ -799,11 +851,12 @@ EOAPI Efl_Canvas_Object *elm_wdg_item_focus_next_object_get(const Eo *obj, Elm_F
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI void elm_wdg_item_focus_next_object_set(Eo *obj, Efl_Canvas_Object *next, Elm_Focus_Direction dir);
+EOAPI void elm_wdg_item_focus_next_object_set(Eo *obj, Efl_Canvas_Object *next, Efl_Ui_Focus_Direction dir);
 
 /**
  * @brief Get the next object item with specific focus direction.
  *
+ * @param[in] obj The object.
  * @param[in] dir Focus direction
  *
  * @return Focus next object item
@@ -812,11 +865,12 @@ EOAPI void elm_wdg_item_focus_next_object_set(Eo *obj, Efl_Canvas_Object *next,
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI Elm_Widget_Item *elm_wdg_item_focus_next_item_get(const Eo *obj, Elm_Focus_Direction dir);
+EOAPI Elm_Widget_Item *elm_wdg_item_focus_next_item_get(const Eo *obj, Efl_Ui_Focus_Direction dir);
 
 /**
  * @brief Set the next object item with specific focus direction.
  *
+ * @param[in] obj The object.
  * @param[in] next_item Focus next object item
  * @param[in] dir Focus direction
  *
@@ -824,6 +878,6 @@ EOAPI Elm_Widget_Item *elm_wdg_item_focus_next_item_get(const Eo *obj, Elm_Focus
  *
  * @ingroup Elm_Widget_Item
  */
-EOAPI void elm_wdg_item_focus_next_item_set(Eo *obj, Elm_Widget_Item *next_item, Elm_Focus_Direction dir);
+EOAPI void elm_wdg_item_focus_next_item_set(Eo *obj, Elm_Widget_Item *next_item, Efl_Ui_Focus_Direction dir);
 
 #endif
