@@ -11,22 +11,56 @@ typedef Eo Efl_Canvas_Object;
 #ifndef _EFL_CANVAS_OBJECT_EO_TYPES
 #define _EFL_CANVAS_OBJECT_EO_TYPES
 
+/** Information of animation events
+ *
+ * @ingroup Efl_Canvas
+ */
+typedef struct _Efl_Canvas_Object_Animation_Event Efl_Canvas_Object_Animation_Event;
+
 
 #endif
+/** Efl canvas object abstract class
+ *
+ * @ingroup Efl_Canvas_Object
+ */
 #define EFL_CANVAS_OBJECT_CLASS efl_canvas_object_class_get()
 
-EWAPI const Eo_Class *efl_canvas_object_class_get(void);
+EWAPI const Efl_Class *efl_canvas_object_class_get(void);
 
-#ifdef EFL_CANVAS_OBJECT_PROTECTED
 /**
- * @brief Sets the legacy type name of this Evas object.
+ * @brief Low-level pointer behaviour by device. See
+ * @ref efl_canvas_object_pointer_mode_get and
+ * @ref efl_canvas_object_pointer_mode_set for more explanation.
  *
- * @param[in] type The type of the object.
+ * @param[in] obj The object.
+ * @param[in] dev The pointer device to set/get the mode. Use @c null for the
+ * default pointer.
+ * @param[in] pointer_mode The pointer mode
+ *
+ * @return @c true if pointer mode was set, @c false otherwise
+ *
+ * @since 1.19
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_type_set(Eo *obj, const char *type);
-#endif
+EOAPI Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_Device *dev, Efl_Input_Object_Pointer_Mode pointer_mode);
+
+/**
+ * @brief Low-level pointer behaviour by device. See
+ * @ref efl_canvas_object_pointer_mode_get and
+ * @ref efl_canvas_object_pointer_mode_set for more explanation.
+ *
+ * @param[in] obj The object.
+ * @param[in] dev The pointer device to set/get the mode. Use @c null for the
+ * default pointer.
+ *
+ * @return The pointer mode
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get(const Eo *obj, Efl_Input_Device *dev);
 
 /**
  * @brief Low-level pointer behaviour.
@@ -34,24 +68,27 @@ EOAPI void efl_canvas_object_type_set(Eo *obj, const char *type);
  * This function has a direct effect on event callbacks related to pointers
  * (mouse, ...).
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB
- * (default), then when mouse is pressed down over this object, events will be
- * restricted to it as source, mouse moves, for example, will be emitted even
- * when the pointer goes outside this objects geometry.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB (default), then
+ * when mouse is pressed down over this object, events will be restricted to it
+ * as source, mouse moves, for example, will be emitted even when the pointer
+ * goes outside this objects geometry.
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_NO_GRAB,
- * then events will be emitted just when inside this object area.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
+ * be emitted just when inside this object area.
  *
- * The default value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB.
+ * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
+ * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
+ * only set/get the mode for the default pointer.
  *
- * @param[in] pointer_mode
+ * @param[in] obj The object.
+ * @param[in] pointer_mode Input pointer mode
+ *
+ * @return @c true if pointer behaviour was set, @c false otherwise
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Event_Object_Pointer_Mode pointer_mode);
+EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Pointer_Mode pointer_mode);
 
 /**
  * @brief Low-level pointer behaviour.
@@ -59,38 +96,42 @@ EOAPI void efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Event_Object_Pointer_
  * This function has a direct effect on event callbacks related to pointers
  * (mouse, ...).
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB
- * (default), then when mouse is pressed down over this object, events will be
- * restricted to it as source, mouse moves, for example, will be emitted even
- * when the pointer goes outside this objects geometry.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB (default), then
+ * when mouse is pressed down over this object, events will be restricted to it
+ * as source, mouse moves, for example, will be emitted even when the pointer
+ * goes outside this objects geometry.
  *
- * If the value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_NO_GRAB,
- * then events will be emitted just when inside this object area.
+ * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
+ * be emitted just when inside this object area.
  *
- * The default value is
- * @ref Efl_Event_Object_Pointer_Mode.EFL_EVENT_OBJECT_POINTER_MODE_AUTO_GRAB.
+ * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
+ * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
+ * only set/get the mode for the default pointer.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Input pointer mode
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Event_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo *obj);
+EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo *obj);
 
 /**
  * @brief Render mode to be used for compositing the Evas object.
  *
- * Only two modes are supported: -
- * @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_BLEND means the object will be
- * merged on top of objects below it using simple alpha compositing. -
- * @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_COPY means this object's pixels
- * will replace everything that is below, making this object opaque.
+ * Only two modes are supported: - @ref EFL_GFX_RENDER_OP_BLEND means the
+ * object will be merged on top of objects below it using simple alpha
+ * compositing. - @ref EFL_GFX_RENDER_OP_COPY means this object's pixels will
+ * replace everything that is below, making this object opaque.
  *
- * Please do not assume that @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_COPY mode
- * can be used to "poke" holes in a window (to see through it), as only the
- * compositor can ensure that. Copy mode should only be used with otherwise
- * opaque widgets, or inside non-window surfaces (eg. a transparent background
- * inside a buffer canvas).
+ * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
+ * "poke" holes in a window (to see through it), as only the compositor can
+ * ensure that. Copy mode should only be used with otherwise opaque widgets or
+ * inside non-window surfaces (eg. a transparent background inside a buffer
+ * canvas).
  *
+ * @param[in] obj The object.
  * @param[in] render_op Blend or copy.
  *
  * @ingroup Efl_Canvas_Object
@@ -100,17 +141,18 @@ EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op)
 /**
  * @brief Render mode to be used for compositing the Evas object.
  *
- * Only two modes are supported: -
- * @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_BLEND means the object will be
- * merged on top of objects below it using simple alpha compositing. -
- * @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_COPY means this object's pixels
- * will replace everything that is below, making this object opaque.
+ * Only two modes are supported: - @ref EFL_GFX_RENDER_OP_BLEND means the
+ * object will be merged on top of objects below it using simple alpha
+ * compositing. - @ref EFL_GFX_RENDER_OP_COPY means this object's pixels will
+ * replace everything that is below, making this object opaque.
  *
- * Please do not assume that @ref Efl_Gfx_Render_Op.EFL_GFX_RENDER_OP_COPY mode
- * can be used to "poke" holes in a window (to see through it), as only the
- * compositor can ensure that. Copy mode should only be used with otherwise
- * opaque widgets, or inside non-window surfaces (eg. a transparent background
- * inside a buffer canvas).
+ * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
+ * "poke" holes in a window (to see through it), as only the compositor can
+ * ensure that. Copy mode should only be used with otherwise opaque widgets or
+ * inside non-window surfaces (eg. a transparent background inside a buffer
+ * canvas).
+ *
+ * @param[in] obj The object.
  *
  * @return Blend or copy.
  *
@@ -121,17 +163,17 @@ EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
 /**
  * @brief Set whether an Evas object is to freeze (discard) events.
  *
- * If @c freeze is @c true, it will make events on @c obj to be discarded.
+ * If @c freeze is @c true, it will force events on @c obj to be discarded.
  * Unlike @ref efl_canvas_object_pass_events_set, events will not be passed to
  * next lower object. This API can be used for blocking events while @c obj is
- * on transiting.
+ * in transition.
  *
  * If @c freeze is @c false, events will be processed on that object as normal.
  *
- * @warning If you block only key/mouse up events with this API, we won't
- * guarantee the state of the object, that only had key/mouse down events, will
- * be.
+ * @warning If you block only key/mouse up events with this API, you can't be
+ * sure of the state of any objects that have only key/mouse down events.
  *
+ * @param[in] obj The object.
  * @param[in] freeze Pass when @c obj is to freeze events ($true) or not
  * ($false).
  *
@@ -144,6 +186,8 @@ EOAPI void efl_canvas_object_freeze_events_set(Eo *obj, Eina_Bool freeze);
 /**
  * @brief Determine whether an object is set to freeze (discard) events.
  *
+ * @param[in] obj The object.
+ *
  * @return Pass when @c obj is to freeze events ($true) or not ($false).
  *
  * @since 1.1
@@ -181,17 +225,19 @@ EOAPI Eina_Bool efl_canvas_object_freeze_events_get(const Eo *obj);
  * it gets implicitly removed from the old clipper's domain and is made now to
  * be clipped by its new clipper.
  *
- * @note At the moment the only objects that can validly be used to clip other
- * objects are rectangle objects. All other object types are invalid and the
- * result of using them is undefined. The clip object @c clip must be a valid
- * object, but can also be @c null, in which case the effect of this function
- * is the same as @ref efl_canvas_object_clip_unset on the @c obj object.
+ * If @c clip is @c null, this call will disable clipping for the object i.e.
+ * its visibility and color get detached from the previous clipper. If it
+ * wasn't, this has no effect.
  *
+ * @note Only rectangle and image (masks) objects can be used as clippers.
+ * Anything else will result in undefined behaviour.
+ *
+ * @param[in] obj The object.
  * @param[in] clip The object to clip @c obj by.
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_clip_set(Eo *obj, Efl_Canvas_Object *clip);
+EOAPI void efl_canvas_object_clip_set(Eo *obj, Efl_Canvas_Object *clip) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Get the object clipping @c obj (if any).
@@ -200,6 +246,8 @@ EOAPI void efl_canvas_object_clip_set(Eo *obj, Efl_Canvas_Object *clip);
  * clipped at all, @c null is returned. The object @c obj must be a valid
  * Evas_Object.
  *
+ * @param[in] obj The object.
+ *
  * @return The object to clip @c obj by.
  *
  * @ingroup Efl_Canvas_Object
@@ -216,6 +264,7 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_clip_get(const Eo *obj);
  * If @c repeat is @c false, events occurring on @c obj will be processed only
  * on it.
  *
+ * @param[in] obj The object.
  * @param[in] repeat Whether @c obj is to repeat events ($true) or not
  * ($false).
  *
@@ -226,38 +275,14 @@ EOAPI void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
 /**
  * @brief Determine whether an object is set to repeat events.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether @c obj is to repeat events ($true) or not ($false).
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_repeat_events_get(const Eo *obj);
 
-/**
- * @brief Sets the scaling factor for an Evas object. Does not affect all
- * objects.
- *
- * This will multiply the object's dimension by the given factor, thus altering
- * its geometry (width and height). Useful when you want scalable UI elements,
- * possibly at run time.
- *
- * @note Only text and textblock objects have scaling change handlers. Other
- * objects won't change visually on this call.
- *
- * @param[in] scale The scaling factor. 1.0 means no scaling, default size.
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_scale_set(Eo *obj, double scale);
-
-/**
- * @brief Retrieves the scaling factor for the given Evas object.
- *
- * @return The scaling factor. 1.0 means no scaling, default size.
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI double efl_canvas_object_scale_get(const Eo *obj);
-
 /**
  * @brief Indicates that this object is the keyboard event receiver on its
  * canvas.
@@ -265,8 +290,12 @@ EOAPI double efl_canvas_object_scale_get(const Eo *obj);
  * Changing focus only affects where (key) input events go. There can be only
  * one object focused at any time. If @c focus is @c true, @c obj will be set
  * as the currently focused object and it will receive all keyboard events that
- * are not exclusive key grabs on other objects.
+ * are not exclusive key grabs on other objects. See also
+ * @ref efl_canvas_object_seat_focus_check,
+ * @ref efl_canvas_object_seat_focus_add,
+ * @ref efl_canvas_object_seat_focus_del.
  *
+ * @param[in] obj The object.
  * @param[in] focus @c true when set as focused or @c false otherwise.
  *
  * @ingroup Efl_Canvas_Object
@@ -280,7 +309,12 @@ EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
  * Changing focus only affects where (key) input events go. There can be only
  * one object focused at any time. If @c focus is @c true, @c obj will be set
  * as the currently focused object and it will receive all keyboard events that
- * are not exclusive key grabs on other objects.
+ * are not exclusive key grabs on other objects. See also
+ * @ref efl_canvas_object_seat_focus_check,
+ * @ref efl_canvas_object_seat_focus_add,
+ * @ref efl_canvas_object_seat_focus_del.
+ *
+ * @param[in] obj The object.
  *
  * @return @c true when set as focused or @c false otherwise.
  *
@@ -289,9 +323,91 @@ EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
 EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
 
 /**
- * @brief No description supplied.
+ * @brief Check if this object is focused.
  *
- * @param[in] is_frame
+ * @param[in] obj The object.
+ *
+ * @return @c true if focused by at least one seat or @c false otherwise.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_seat_focus_get(const Eo *obj);
+
+/**
+ * @brief Check if this object is focused by a given seat
+ *
+ * @param[in] obj The object.
+ * @param[in] seat The seat to check if the object is focused. Use @c null for
+ * the default seat.
+ *
+ * @return @c true if focused or @c false otherwise.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_seat_focus_check(Eo *obj, Efl_Input_Device *seat);
+
+/**
+ * @brief Add a seat to the focus list.
+ *
+ * Evas allows the Efl.Canvas.Object to be focused by multiple seats at the
+ * same time. This function adds a new seat to the focus list. In other words,
+ * after the seat is added to the list this object will now be also focused by
+ * this new seat.
+ *
+ * This function generates an @ref EFL_CANVAS_OBJECT_EVENT_FOCUS_DEVICE_IN
+ * event.
+ *
+ * @note The old focus APIs ( @ref evas_object_focus_get, @ref
+ * evas_object_focus_set, @ref efl_canvas_object_key_grab) will still work,
+ * however they will only act on the default seat.
+ *
+ * @param[in] obj The object.
+ * @param[in] seat The seat that should be added to the focus list. Use @c null
+ * for the default seat.
+ *
+ * @return @c true if the focus has been set or @c false otherwise.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_seat_focus_add(Eo *obj, Efl_Input_Device *seat);
+
+/**
+ * @brief Remove a seat from the focus list.
+ *
+ * Removing an seat from the focus list is an unfocus operation, thus it will
+ * generate an @ref EFL_CANVAS_OBJECT_EVENT_FOCUS_DEVICE_OUT event.
+ *
+ * @param[in] obj The object.
+ * @param[in] seat The seat that should be removed from the focus list. Use
+ * @c null for the default seat.
+ *
+ * @return @c true if the seat was removed from the focus list or @c false
+ * otherwise.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat);
+
+/**
+ * @brief If @c true the object belongs to the window border decorations.
+ *
+ * This will be @c false by default, and should be @c false for all objects
+ * created by the application, unless swallowed in some very specific parts of
+ * the window.
+ *
+ * It is very unlikely that an application needs to call this manually, as the
+ * window will handle this feature automatically.
+ *
+ * @param[in] obj The object.
+ * @param[in] is_frame @c true if the object is a frame, @c false otherwise
  *
  * @since 1.2
  *
@@ -299,7 +415,19 @@ EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
  */
 EOAPI void efl_canvas_object_is_frame_object_set(Eo *obj, Eina_Bool is_frame);
 
-/** No description supplied.
+/**
+ * @brief If @c true the object belongs to the window border decorations.
+ *
+ * This will be @c false by default, and should be @c false for all objects
+ * created by the application, unless swallowed in some very specific parts of
+ * the window.
+ *
+ * It is very unlikely that an application needs to call this manually, as the
+ * window will handle this feature automatically.
+ *
+ * @param[in] obj The object.
+ *
+ * @return @c true if the object is a frame, @c false otherwise
  *
  * @since 1.2
  *
@@ -318,6 +446,7 @@ EOAPI Eina_Bool efl_canvas_object_is_frame_object_get(const Eo *obj);
  * @warning By using precise point collision detection you'll be making Evas
  * more resource intensive.
  *
+ * @param[in] obj The object.
  * @param[in] precise Whether to use precise point collision detection or not.
  * The default value is false.
  *
@@ -329,6 +458,8 @@ EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
  * @brief Determine whether an object is set to use precise point collision
  * detection.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to use precise point collision detection or not. The default
  * value is false.
  *
@@ -337,8 +468,8 @@ EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
 EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
 
 /**
- * @brief Set whether events on a smart object's member should get propagated
- * up to its parent.
+ * @brief Set whether events on a smart object's member should be propagated up
+ * to its parent.
  *
  * This function has no effect if @c obj is not a member of a smart object.
  *
@@ -351,6 +482,7 @@ EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
  * @ref efl_canvas_object_pass_events_set,
  * @ref efl_canvas_object_freeze_events_set.
  *
+ * @param[in] obj The object.
  * @param[in] propagate Whether to propagate events ($true) or not ($false).
  *
  * @ingroup Efl_Canvas_Object
@@ -364,6 +496,8 @@ EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
  * @ref efl_canvas_object_pass_events_get,
  * @ref efl_canvas_object_freeze_events_get.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to propagate events ($true) or not ($false).
  *
  * @ingroup Efl_Canvas_Object
@@ -377,12 +511,13 @@ EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
  * will be triggered on the next lower object (that is not set to pass events),
  * instead (see @ref evas_object_below_get).
  *
- * If @c pass is @c false, events will be processed on that object as normal.
+ * If @c pass is @c false events will be processed on that object as normal.
  *
  * See also @ref efl_canvas_object_repeat_events_set,
  * @ref efl_canvas_object_propagate_events_set,
  * @ref efl_canvas_object_freeze_events_set.
  *
+ * @param[in] obj The object.
  * @param[in] pass Whether @c obj is to pass events ($true) or not ($false).
  *
  * @ingroup Efl_Canvas_Object
@@ -396,6 +531,8 @@ EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
  * @ref efl_canvas_object_propagate_events_get,
  * @ref efl_canvas_object_freeze_events_get.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether @c obj is to pass events ($true) or not ($false).
  *
  * @ingroup Efl_Canvas_Object
@@ -406,6 +543,7 @@ EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
  * @brief Sets whether or not the given Evas object is to be drawn
  * anti-aliased.
  *
+ * @param[in] obj The object.
  * @param[in] anti_alias @c true if the object is to be anti_aliased, @c false
  * otherwise.
  *
@@ -417,6 +555,8 @@ EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
  * @brief Retrieves whether or not the given Evas object is to be drawn
  * anti_aliased.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the object is to be anti_aliased, @c false otherwise.
  *
  * @ingroup Efl_Canvas_Object
@@ -426,8 +566,8 @@ EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
 /**
  * @brief Return a list of objects currently clipped by @c obj.
  *
- * This returns the internal list handle that contains all objects clipped by
- * the object @c obj. If none are clipped by it, the call returns @c null. This
+ * This returns the internal list handle containing all objects clipped by the
+ * object @c obj. If none are clipped by it, the call returns @c null. This
  * list is only valid until the clip list is changed and should be fetched
  * again with another call to this function if any objects being clipped by
  * this object are unclipped, clipped by a new object, deleted or get the
@@ -435,23 +575,26 @@ EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
  * should not be used anymore after that point. Any use of the list after this
  * may have undefined results, possibly leading to crashes.
  *
- * See also @ref efl_canvas_object_clip_get and
- * @ref efl_canvas_object_clip_unset.
+ * See also @ref efl_canvas_object_clip_get.
+ *
+ * @param[in] obj The object.
  *
  * @return An iterator over the list of objects clipped by @c obj.
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Iterator *efl_canvas_object_clipees_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_canvas_object_clipees_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 #ifdef EFL_CANVAS_OBJECT_PROTECTED
 /**
  * @brief Gets the parent smart object of a given Evas object, if it has one.
  *
- * This can be different from @ref eo_parent_get because this one is used
+ * This can be different from @ref efl_parent_get because this one is used
  * internally for rendering and the normal parent is what the user expects to
  * be the parent.
  *
+ * @param[in] obj The object.
+ *
  * @return The parent smart object of @c obj or @c null.
  *
  * @since 1.18
@@ -467,6 +610,7 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_render_parent_get(const Eo *obj);
  * inherit the paragraph direction from the given object. The default paragraph
  * direction is @c inherit.
  *
+ * @param[in] obj The object.
  * @param[in] dir Paragraph direction for the given object.
  *
  * @ingroup Efl_Canvas_Object
@@ -479,6 +623,8 @@ EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirecti
  * inherit the paragraph direction from the given object. The default paragraph
  * direction is @c inherit.
  *
+ * @param[in] obj The object.
+ *
  * @return Paragraph direction for the given object.
  *
  * @ingroup Efl_Canvas_Object
@@ -486,60 +632,17 @@ EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirecti
 EOAPI Efl_Text_Bidirectional_Type efl_canvas_object_paragraph_direction_get(const Eo *obj);
 
 /**
- * @brief Disable all rendering on the canvas.
+ * @brief Test if any object is clipped by @c obj.
  *
- * This flag will be used to indicate to Evas that this object should never be
- * rendered on the canvas under any circurmstances. In particular, this is
- * useful to avoid drawing clipper objects (or masks) even when they don't clip
- * any object. This can also be used to replace the old source_visible flag
- * with proxy objects.
+ * @param[in] obj The object.
  *
- * This is different to the visible property, as even visible objects marked as
- * "no-render" will never appear on screen. But those objects can still be used
- * as proxy sources or clippers. When hidden, all "no-render" objects will
- * completely disappear from the canvas, and hide their clippees or be
- * invisible when used as proxy sources.
- *
- * @param[in] enable Enable "no-render" mode.
- *
- * @since 1.15
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
-
-/**
- * @brief Returns the state of the "no-render" flag, which means, when true,
- * that an object should never be rendered on the canvas.
- *
- * This flag can be used to avoid rendering visible clippers on the canvas,
- * even if they currently don't clip any object.
- *
- * @return Enable "no-render" mode.
- *
- * @since 1.15
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-#ifdef EFL_CANVAS_OBJECT_PROTECTED
-/** Internal function. Do not use.
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_legacy_ctor(Eo *obj);
-#endif
-#endif
-
-/** Test if any object is clipped by @c obj.
+ * @return @c true if any object is clipped by @c obj, @c false otherwise
  *
  * @since 1.8
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj);
+EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Requests @c keyname key events be directed to @c obj.
@@ -567,11 +670,12 @@ EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj);
  * @ref efl_canvas_object_key_focus_get, @ref efl_canvas_object_key_focus_set,
  * @ref evas_focus_get, @ref evas_key_modifier_add.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The key to request events for.
- * @param[in] modifiers A mask of modifiers that must be present to trigger the
- * event.
- * @param[in] not_modifiers A mask of modifiers that must not be present to
+ * @param[in] modifiers A combinaison of modifier keys that must be present to
  * trigger the event.
+ * @param[in] not_modifiers A combinaison of modifier keys that must not be
+ * present to trigger the event.
  * @param[in] exclusive Request that the @c obj is the only object receiving
  * the @c keyname events.
  *
@@ -579,7 +683,7 @@ EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, Eina_Bool exclusive);
+EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(2);
 
 /**
  * @brief Removes the grab on @c keyname key events by @c obj.
@@ -589,200 +693,135 @@ EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Evas_Mo
  *
  * See also @ref efl_canvas_object_key_grab,
  * @ref efl_canvas_object_key_focus_get, @ref efl_canvas_object_key_focus_set,
- * @ref evas_focus_get.
+ * and the legacy API evas_focus_get.
  *
- * @param[in] keyname he key the grab is set for.
+ * @param[in] obj The object.
+ * @param[in] keyname The key the grab is set for.
  * @param[in] modifiers A mask of modifiers that must be present to trigger the
  * event.
- * @param[in] not_modifiers A mask of modifiers that mus not not be present to
+ * @param[in] not_modifiers A mask of modifiers that must not not be present to
  * trigger the event.
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
+EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers) EINA_ARG_NONNULL(2);
 
 /**
- * @brief Disable/cease clipping on a clipped @c obj object.
+ * @brief Disable all rendering on the canvas.
  *
- * This function disables clipping for the object @c obj, if it was already
- * clipped, i.e., its visibility and color get detached from the previous
- * clipper. If it wasn't, this has no effect. The object @c obj must be a valid
- * Evas_Object.
+ * This flag will be used to indicate to Evas that this object should never be
+ * rendered on the canvas under any circumstances. In particular, this is
+ * useful to avoid drawing clipper objects (or masks) even when they don't clip
+ * any object. This can also be used to replace the old source_visible flag
+ * with proxy objects.
  *
- * See also @ref efl_canvas_object_clip_set, @ref efl_canvas_object_clipees_get
- * and @ref efl_canvas_object_clip_get.
+ * This is different to the visible property, as even visible objects marked as
+ * "no-render" will never appear on screen. But those objects can still be used
+ * as proxy sources or clippers. When hidden, all "no-render" objects will
+ * completely disappear from the canvas, and hide their clippees or be
+ * invisible when used as proxy sources.
+ *
+ * @param[in] obj The object.
+ * @param[in] enable Enable "no-render" mode.
+ *
+ * @since 1.15
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_clip_unset(Eo *obj);
+EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_IN;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_OUT;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_DOWN;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_UP;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_MOVE;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MOUSE_WHEEL;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MULTI_DOWN;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MULTI_UP;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_MULTI_MOVE;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_FREE;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_KEY_DOWN;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_KEY_UP;
-#endif
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_FOCUS_IN;
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_FOCUS_OUT;
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_DEL;
-#endif
-#ifdef EFL_CANVAS_OBJECT_BETA
-EOAPI extern const Eo_Event_Description _EFL_CANVAS_OBJECT_EVENT_HOLD;
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse In Event
+/**
+ * @brief Returns the state of the "no-render" flag, which means, when true,
+ * that an object should never be rendered on the canvas.
+ *
+ * This flag can be used to avoid rendering visible clippers on the canvas,
+ * even if they currently don't clip any object.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Enable "no-render" mode.
+ *
+ * @since 1.15
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_IN (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_IN))
-#endif
+EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse Out Event
+/**
+ * @brief Returns whether the coords are logically inside the object.
+ *
+ * When this function is called it will return a value of either @c false or
+ * @c true, depending on if the coords are inside the object's current
+ * geometry.
+ *
+ * A return value of @c true indicates the position is logically inside the
+ * object, and @c false implies it is logically outside the object.
+ *
+ * If @c e is not a valid object, the return value is undefined.
+ *
+ * @param[in] obj The object.
+ * @param[in] pos The position in pixels.
+ *
+ * @return @c true if the coords are inside the object, @c false otherwise
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_OUT (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_OUT))
-#endif
+EOAPI Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse Button Down Event
+/**
+ * @brief Set the @c animation which starts when the given @c desc happens to
+ * the object.
+ *
+ * @param[in] obj The object.
+ * @param[in] desc The event description for which the given @c animation is
+ * set.
+ * @param[in] animation The animation which starts when the given @c desc
+ * happens to the object.
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_DOWN (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_DOWN))
-#endif
+EOAPI void efl_canvas_object_event_animation_set(Eo *obj, const Efl_Event_Description *desc, Efl_Canvas_Animation *animation);
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse Button Up Event
+/**
+ * @brief Set the @c animation which starts when the given @c desc happens to
+ * the object.
+ *
+ * @param[in] obj The object.
+ * @param[in] desc The event description for which the given @c animation is
+ * set.
+ *
+ * @return The animation which starts when the given @c desc happens to the
+ * object.
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_UP (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_UP))
-#endif
+EOAPI Efl_Canvas_Animation *efl_canvas_object_event_animation_get(const Eo *obj, const Efl_Event_Description *desc);
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse Move Event
+EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIM_STARTED;
+
+/** Animation is started.
+ * @return Efl_Canvas_Object_Animation_Event
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_MOVE (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_MOVE))
-#endif
+#define EFL_CANVAS_OBJECT_EVENT_ANIM_STARTED (&(_EFL_CANVAS_OBJECT_EVENT_ANIM_STARTED))
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse Wheel Event
+EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIM_RUNNING;
+
+/** Animation is running.
+ * @return Efl_Canvas_Object_Animation_Event
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MOUSE_WHEEL (&(_EFL_CANVAS_OBJECT_EVENT_MOUSE_WHEEL))
-#endif
+#define EFL_CANVAS_OBJECT_EVENT_ANIM_RUNNING (&(_EFL_CANVAS_OBJECT_EVENT_ANIM_RUNNING))
 
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse-touch Down Event
+EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIM_ENDED;
+
+/** Animation is ended.
+ * @return Efl_Canvas_Object_Animation_Event
  *
  * @ingroup Efl_Canvas_Object
  */
-#define EFL_CANVAS_OBJECT_EVENT_MULTI_DOWN (&(_EFL_CANVAS_OBJECT_EVENT_MULTI_DOWN))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Mouse-touch Up Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_MULTI_UP (&(_EFL_CANVAS_OBJECT_EVENT_MULTI_UP))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Multi-touch Move Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_MULTI_MOVE (&(_EFL_CANVAS_OBJECT_EVENT_MULTI_MOVE))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Object Being Freed (Called after Del)
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_FREE (&(_EFL_CANVAS_OBJECT_EVENT_FREE))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Key Press Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_KEY_DOWN (&(_EFL_CANVAS_OBJECT_EVENT_KEY_DOWN))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Key Release Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_KEY_UP (&(_EFL_CANVAS_OBJECT_EVENT_KEY_UP))
-#endif
-
-/** Focus In Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_FOCUS_IN (&(_EFL_CANVAS_OBJECT_EVENT_FOCUS_IN))
-
-/** Focus Out Event
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_FOCUS_OUT (&(_EFL_CANVAS_OBJECT_EVENT_FOCUS_OUT))
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Object Being Deleted (called before Free)
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_DEL (&(_EFL_CANVAS_OBJECT_EVENT_DEL))
-#endif
-
-#ifdef EFL_CANVAS_OBJECT_BETA
-/** Events go on/off hold
- *
- * @ingroup Efl_Canvas_Object
- */
-#define EFL_CANVAS_OBJECT_EVENT_HOLD (&(_EFL_CANVAS_OBJECT_EVENT_HOLD))
-#endif
+#define EFL_CANVAS_OBJECT_EVENT_ANIM_ENDED (&(_EFL_CANVAS_OBJECT_EVENT_ANIM_ENDED))
 
 #endif
